@@ -206,9 +206,13 @@ async def start_subprocess(
         info.dwFlags = subprocess.STARTF_USESHOWWINDOW
         info.wShowWindow = subprocess.SW_HIDE
 
+        # 'No module named c' is a bug and occurs when the Python debugger
+        # attaches itself to the subprocess. You can prevent this by disabling
+        # it in the IDE e.g. vscode python launche config -> subprocess: false, 
+        # or by using a different executor, such as cmd /c python ...
+        # If you use cmd /c, you have a command length restriction (Windows sucks)
+
         process = await asyncio.create_subprocess_exec(
-            "cmd",
-            "/c",
             os.path.join(python_dir, "python"),
             *params,
             stdout=stdout,
@@ -217,6 +221,7 @@ async def start_subprocess(
             startupinfo=info,
             creationflags=subprocess.CREATE_NEW_PROCESS_GROUP | subprocess.CREATE_NEW_CONSOLE
         )
+
     else:
         raise NotImplementedError()
 
